=begin
 Copyright 2008, AlexM

 THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
 IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

 Author :          AlexM
 Date Original :   2008-12-21(2009-05-20/Adjusting for publication)
=end

module ArchTools

def self.set_standard_views(flag)
	axes = get_model_axes
	xaxis = axes.at(0); yaxis = axes.at(1); zaxis = axes.at(2)
	model = Sketchup.active_model
	view = model.active_view
	camera = view.camera
	target = ORIGIN
	up = nil
	case flag
	when 0 #Top
		eye = target+zaxis
		up =  yaxis
	when 1 #Front
		eye = target+yaxis.reverse
	when 2 #Right
		eye = target+xaxis
	when 3 #Back
		eye = target+yaxis
	when 4 #Left
		eye = target+xaxis.reverse
	when 5 #Bottom
		eye = target+zaxis.reverse
		up =  yaxis
	when 6 #Iso Auto
		vec = camera.direction
		xaxis.reverse! if vec.angle_between(xaxis) < Math::PI/2
		yaxis.reverse! if vec.angle_between(yaxis) < Math::PI/2
		zaxis.reverse! if vec.angle_between(zaxis) < Math::PI/2
		eye = target+Geom::Vector3d.linear_combination(0.5, xaxis, 0.5, yaxis, 0.5, zaxis)
	when 7 #Iso SW
		eye = target+Geom::Vector3d.linear_combination(0.5, xaxis.reverse, 0.5, yaxis.reverse, 0.5, zaxis)
	when 8 #Iso SE
		eye = target+Geom::Vector3d.linear_combination(0.5, xaxis, 0.5, yaxis.reverse, 0.5, zaxis)
	when 9 #Iso NE
		eye = target+Geom::Vector3d.linear_combination(0.5, xaxis, 0.5, yaxis, 0.5, zaxis)
	when 10 #Iso NW
		eye = target+Geom::Vector3d.linear_combination(0.5, xaxis.reverse, 0.5, yaxis, 0.5, zaxis)
	end
	up = zaxis if not up
	camera.set eye, target, up
	view.zoom_extents
	view.zoom 0.95 #correct
	#update_info
end#def


end#module
#---------------------------------------------------------------------------------------------------
def ArchTools::get_model_axes(operation=true)
	model = Sketchup.active_model
	ents = model.active_entities
	model.start_operation "Get Axes" if operation
	tr = ents.add_group(ents.add_group).transformation
	model.abort_operation if operation
	return tr.xaxis, tr.yaxis, tr.zaxis#, tr.origin
end#def
#---------------------------------------------------------------------------------------------------
def ArchTools::load_single_menu(cmds, menu=nil, toolbar=nil)
	load_items_menu = proc { |ind|
		for cmdItem in cmds
			ind.add_separator if cmdItem.at(1)
			ind.add_item(cmdItem.at(0))
			ind.add_separator if cmdItem.at(2)
		end
	}
	if menu
		mnu = UI.menu(menu.at(0))
		1.upto menu.length-1 do |i| mnu=mnu.add_submenu(menu.at(i)) end
		load_items_menu.call(mnu)
	end
	if toolbar
		tlb = UI::Toolbar.new(toolbar) 
		load_items_menu.call(tlb)
		state = tlb.get_last_state 
		tlb.show    if (state == -1)
		tlb.restore if (state == 1)
	end
end#def
#---------------------------------------------------------------------------------------------------
file_name = File.basename(__FILE__)
if not file_loaded?(file_name)
cmds = []
#---------------------------------------------------------------------------------------------------
viewname = "Top"
cmd = UI::Command.new(viewname) {ArchTools::set_standard_views 0}
cmd.tooltip = cmd.menu_text = cmd.status_bar_text = viewname
if $AT__MENU_LOADER
	$AT__MENU_LOADER.menu_load(0, fullname, cmd, ["Camera", 2.0, " AT   Camera", 2.0, [cmd]])
else
	cmds << [cmd] #cmds[0]
end
#---------------------------------------------------------------------------------------------------
viewname = "Front"
cmd = UI::Command.new(viewname) {ArchTools::set_standard_views 1}
cmd.tooltip = cmd.menu_text = cmd.status_bar_text = viewname
if $AT__MENU_LOADER
	$AT__MENU_LOADER.menu_load(0, fullname, cmd, ["Camera", 2.0, " AT   Camera", 3.0, [cmd]])
else
	cmds << [cmd] #cmds[0]
end
#---------------------------------------------------------------------------------------------------
viewname = "Right"
cmd = UI::Command.new(viewname) {ArchTools::set_standard_views 2}
cmd.tooltip = cmd.menu_text = cmd.status_bar_text = viewname
if $AT__MENU_LOADER
	$AT__MENU_LOADER.menu_load(0, fullname, cmd, ["Camera", 2.0, " AT   Camera", 4.0, [cmd]])
else
	cmds << [cmd] #cmds[0]
end
#---------------------------------------------------------------------------------------------------
viewname = "Back"
cmd = UI::Command.new(viewname) {ArchTools::set_standard_views 3}
cmd.tooltip = cmd.menu_text = cmd.status_bar_text = viewname
if $AT__MENU_LOADER
	$AT__MENU_LOADER.menu_load(0, fullname, cmd, ["Camera", 2.0, " AT   Camera", 5.0, [cmd]])
else
	cmds << [cmd] #cmds[0]
end
#---------------------------------------------------------------------------------------------------
viewname = "Left"
cmd = UI::Command.new(viewname) {ArchTools::set_standard_views 4}
cmd.tooltip = cmd.menu_text = cmd.status_bar_text = viewname
if $AT__MENU_LOADER
	$AT__MENU_LOADER.menu_load(0, fullname, cmd, ["Camera", 2.0, " AT   Camera", 6.0, [cmd]])
else
	cmds << [cmd] #cmds[0]
end

#---------------------------------------------------------------------------------------------------
viewname = "Bottom"
cmd = UI::Command.new(viewname) {ArchTools::set_standard_views 5}
cmd.tooltip = cmd.menu_text = cmd.status_bar_text = viewname
if $AT__MENU_LOADER
	$AT__MENU_LOADER.menu_load(0, fullname, cmd, ["Camera", 2.0, " AT   Camera", 7.0, [cmd]])
else
	cmds << [cmd] #cmds[0]
end
#---------------------------------------------------------------------------------------------------
viewname = "Iso Auto"
cmd = UI::Command.new(viewname) {ArchTools::set_standard_views 6}
cmd.tooltip = cmd.menu_text = cmd.status_bar_text = viewname
if $AT__MENU_LOADER
	$AT__MENU_LOADER.menu_load(0, fullname, cmd, ["Camera", 2.0, " AT   Camera", 8.0, [cmd, true]])
else
	cmds << [cmd, true] #cmds[0]
end
#---------------------------------------------------------------------------------------------------
viewname = "Iso SW"
cmd = UI::Command.new(viewname) {ArchTools::set_standard_views 7}
cmd.tooltip = cmd.menu_text = cmd.status_bar_text = viewname
if $AT__MENU_LOADER
	$AT__MENU_LOADER.menu_load(0, fullname, cmd, ["Camera", 2.0, " AT   Camera", 9.0, [cmd]])
else
	cmds << [cmd] #cmds[0]
end
#---------------------------------------------------------------------------------------------------
viewname = "Iso SE"
cmd = UI::Command.new(viewname) {ArchTools::set_standard_views 8}
cmd.tooltip = cmd.menu_text = cmd.status_bar_text = viewname
if $AT__MENU_LOADER
	$AT__MENU_LOADER.menu_load(0, fullname, cmd, ["Camera", 2.0, " AT   Camera", 10.0, [cmd]])
else
	cmds << [cmd] #cmds[0]
end
#---------------------------------------------------------------------------------------------------
viewname = "Iso NE"
cmd = UI::Command.new(viewname) {ArchTools::set_standard_views 9}
cmd.tooltip = cmd.menu_text = cmd.status_bar_text = viewname
if $AT__MENU_LOADER
	$AT__MENU_LOADER.menu_load(0, fullname, cmd, ["Camera", 2.0, " AT   Camera", 11.0, [cmd]])
else
	cmds << [cmd] #cmds[0]
end
#---------------------------------------------------------------------------------------------------
viewname = "Iso NW"
cmd = UI::Command.new(viewname) {ArchTools::set_standard_views 10}
cmd.tooltip = cmd.menu_text = cmd.status_bar_text = viewname
if $AT__MENU_LOADER
	$AT__MENU_LOADER.menu_load(0, fullname, cmd, ["Camera", 2.0, " AT   Camera", 12.0, [cmd]])
else
	cmds << [cmd] #cmds[0]
end
#---------------------------------------------------------------------------------------------------
ArchTools::load_single_menu(cmds, ["Camera", "Standard Extended"]) unless $AT__MENU_LOADER
file_loaded(file_name)
end
file_name = fullname = viewname = cmd = cmds = nil